@@ -65,8 +65,9 @@ search.arima <- function(x, d=NA, D=NA, max.p=5, max.q=5,
       num.cores <- detectCores()
     }
     cl <- makeCluster(num.cores)
-    #exporting the max.order object in the cluster
-    #clusterExport(cl,c("max.order"))
+    #exporting the objects needed in all nodes of the cluster
+    clusterExport(cl, c("max.order"), envir=environment())
+
     all.models <- parLapply(cl = cl, X = to.check, fun = par.all.arima)
     stopCluster(cl = cl)
 
@@ -586,7 +587,7 @@ fitted.Arima <- function(object, h = 1, ...) {
       return(x - object$residuals)
     }
     else {
-      fits <- InvBoxCox(BoxCox(x, object$lambda) - object$residuals, object$lambda, NULL, var(object$residuals, na.rm=TRUE))
+      fits <- InvBoxCox(BoxCox(x, object$lambda) - object$residuals, object$lambda, NULL, object$sigma2)
       return(fits)
     }
   }
