@@ -215,7 +215,7 @@ tsoutliers <- function(x, iterate=2, lambda=NULL) {
   }
 
   # Limits of acceptable residuals
-  resid.q <- quantile(resid, prob = c(0.25, 0.75), na.rm = TRUE)
+  resid.q <- quantile(resid, probs = c(0.25, 0.75), na.rm = TRUE)
   iqr <- diff(resid.q)
   limits <- resid.q + 3 * iqr * c(-1, 1)
 
@@ -235,9 +235,13 @@ tsoutliers <- function(x, iterate=2, lambda=NULL) {
     tmp <- tsoutliers(x, iterate = 1, lambda = lambda)
     if (length(tmp$index) > 0) # Found some more
     {
-      outliers <- sort(c(outliers, tmp$index))
+      outliers <- sort(unique(c(outliers, tmp$index)))
       x[outliers] <- NA
-      x <- na.interp(x, lambda = lambda)
+      if(sum(!is.na(x)) == 1L) {
+        # Only one non-missing value
+        x[is.na(x)] <- x[!is.na(x)]
+      } else
+        x <- na.interp(x, lambda = lambda)
     }
   }
 
