@@ -67,7 +67,7 @@
 #' @param allowmean If \code{TRUE}, models with a non-zero mean are considered.
 #' @param parallel If \code{TRUE} and \code{stepwise = FALSE}, then the
 #' specification search is done in parallel. This can give a significant
-#' speedup on mutlicore machines.
+#' speedup on multicore machines.
 #' @param num.cores Allows the user to specify the amount of parallel processes
 #' to be used if \code{parallel = TRUE} and \code{stepwise = FALSE}. If
 #' \code{NULL}, then the number of logical cores is automatically detected and
@@ -129,6 +129,12 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
 
   # Trim initial missing values
   x <- subset(x, start=firstnonmiss)
+  if(!is.null(xreg)) {
+    if(!is.numeric(xreg))
+      stop("xreg should be a numeric matrix or a numeric vector")
+    xreg <- as.matrix(xreg)
+    xreg <- xreg[firstnonmiss:NROW(xreg),,drop=FALSE]
+  }
 
   # Check for constant data
   if (is.constant(x)) {
@@ -184,9 +190,6 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
 
   # Check xreg and do regression if necessary
   if (!is.null(xreg)) {
-    if(!is.numeric(xreg))
-      stop("xreg should be a numeric matrix or a numeric vector")
-    xreg <- as.matrix(xreg)
     if (is.null(colnames(xreg))) {
       colnames(xreg) <- if (ncol(xreg) == 1) "xreg" else paste("xreg", 1:ncol(xreg), sep = "")
     }
@@ -285,7 +288,10 @@ auto.arima <- function(y, d=NA, D=NA, max.p=5, max.q=5,
     dx <- diff(dx, differences = d, lag = 1)
   }
 
-  if (is.constant(dx)) {
+
+  if(length(dx) == 0L)
+    stop("Not enough data to proceed")
+  else if (is.constant(dx)) {
     if (is.null(xreg)) {
       if (D > 0 && d == 0) {
         fit <- Arima(x, order = c(0, d, 0), seasonal = list(order = c(0, D, 0), period = m), include.constant = TRUE, fixed = mean(dx/m, na.rm = TRUE), method = method, ...)
@@ -683,7 +689,7 @@ myarima <- function(x, order = c(0, 0, 0), seasonal = c(0, 0, 0), constant=TRUE,
   missing <- is.na(x)
   firstnonmiss <- head(which(!missing),1)
   lastnonmiss <- tail(which(!missing),1)
-  n <- lastnonmiss - firstnonmiss + 1
+  n <- sum(!missing[firstnonmiss:lastnonmiss])
   m <- frequency(x)
   use.season <- (sum(seasonal) > 0) & m > 0
   diffs <- order[2] + seasonal[2]
@@ -695,7 +701,7 @@ myarima <- function(x, order = c(0, 0, 0), seasonal = c(0, 0, 0), constant=TRUE,
     }
   }
   if (diffs == 1 && constant) {
-    xreg <- `colnames<-`(cbind(drift = 1:length(x), xreg), 
+    xreg <- `colnames<-`(cbind(drift = 1:length(x), xreg),
       make.unique(c("drift", if(is.null(colnames(xreg)) && !is.null(xreg)) rep("", NCOL(xreg)) else colnames(xreg))))
     if (use.season) {
       suppressWarnings(fit <- try(stats::arima(x = x, order = order, seasonal = list(order = seasonal, period = m), xreg = xreg, method = method, ...), silent = TRUE))
@@ -774,9 +780,10 @@ myarima <- function(x, order = c(0, 0, 0), seasonal = c(0, 0, 0), constant=TRUE,
         else fit$ic <- Inf
       }
     }
-    if (minroot < 1 + 1e-2) { # Previously 1+1e-3
+    # Avoid bad models
+    if (minroot < 1 + 1e-2 | checkarima(fit)) {
       fit$ic <- Inf
-    } # Don't like this model
+    }
     if (trace) {
       cat("\n", arima.string(fit, padding = TRUE), ":", fit$ic)
     }
@@ -864,9 +871,15 @@ arima.string <- function(object, padding=FALSE) {
 
 #' @export
 summary.Arima <- function(object, ...) {
-  print(object)
+  class(object) <- c("summary.Arima", class(object))
+  object
+}
+
+#' @export
+print.summary.Arima <- function(x, ...) {
+  NextMethod()
   cat("\nTraining set error measures:\n")
-  print(accuracy(object))
+  print(accuracy(x))
 }
 
 # Check that Arima object has positive coefficient variances without returning warnings
