@@ -445,13 +445,13 @@ simulate.Arima <- function(object, nsim=length(object$x), seed=NULL, xreg=NULL,
       zeros <- object$arma[5] * object$arma[7]
       sim <- arima.sim(model, nsim, innov = e)
       sim <- diffinv(sim, lag = object$arma[5], differences = object$arma[7])[-(1:zeros)]
-      sim <- ts(tail(sim, nsim) + xm)
+      sim <- tail(sim, nsim) + xm
     }
     else {
-      sim <- ts(tail(arima.sim(model, nsim, innov = e), nsim) + xm)
+      sim <- tail(arima.sim(model, nsim, innov = e), nsim) + xm
     }
-    if(nsim==n)
-      tsp(sim) <- tsp(x)
+    sim <- ts(sim, start=tsp(x)[1], frequency=tsp(x)[3])
+
     # If model is non-stationary, then condition simulated data on first observation
     if (model$order[2] > 0 || flag.seasonal.diff) {
       sim <- sim - sim[1] + x[1]
@@ -539,7 +539,7 @@ simulate.lagwalk <- function(object, nsim=length(object$x), seed=NULL,
     e <- sample(res, nsim, replace = TRUE)
   }
   else if (is.null(innov)) {
-    se <- sqrt(object$sigma2*nsim + (nsim*object$par$drift.se)^2)
+    se <- sqrt(object$sigma2)
     e <- rnorm(nsim, 0, se)
   } else {
     e <- innov
@@ -579,7 +579,8 @@ simulate.lagwalk <- function(object, nsim=length(object$x), seed=NULL,
   }
 
   # Construct simulated ts
-  sim <- rep_len(start, nsim) + seq_len(nsim)*object$par$drift + cumulative_e
+  simdrift <- object$par$drift + rnorm(1,0,object$par$drift.se)
+  sim <- rep_len(start, nsim) + seq_len(nsim)*simdrift + cumulative_e
   if(!is.null(lambda)){
     sim <- InvBoxCox(sim, lambda)
   }
